@@ -261,7 +261,7 @@ class ZeroSerobjProtocol(SerobjProtocolBase):
             if args is not None and not isinstance(args, list):
                 raise TypeError(
                     "'{}' result should be list of args "
-                    "(like [{{'name': '', 'value': '123'}, {{'name': 'kw', 'value': 'kw123'}}])".format(
+                    "(like [{{'name': '', 'value': '123'}}, {{'name': 'kw', 'value': 'kw123'}}])".format(
                         args_method_name
                     )
                 )
@@ -282,7 +282,10 @@ class ZeroSerobjProtocol(SerobjProtocolBase):
 
     @classmethod
     def _is_proto_object(cls, obj):
-        return isinstance(obj, dict) and _SCHEMA_VALIDATOR.validate(obj)
+        try:
+            return isinstance(obj, dict) and _SCHEMA_VALIDATOR.validate(obj)
+        except Exception:
+            return False
 
     @classmethod
     def _check_unsupported_types(cls, obj):
@@ -541,8 +544,12 @@ class ZeroSerobjProtocol(SerobjProtocolBase):
             if allow_raw_value and not isinstance(payload, dict):
                 return True
 
-            if _SCHEMA_VALIDATOR.validate(payload):
-                return True
+            try:
+                if _SCHEMA_VALIDATOR.validate(payload):
+                    return True
+            except Exception as e:
+                if raise_exception:
+                    raise e
 
             if raise_exception:
                 raise ValueError(
